@@ -130,11 +130,27 @@ static void
 timezone_changed (GtkWidget *widget, CalendarPrefsDialog *prefs)
 {
 	icaltimezone *zone;
+	icalcomponent *icalcomp, *dl_comp;
 
 	zone = e_timezone_entry_get_timezone (E_TIMEZONE_ENTRY (prefs->timezone));
+	icalcomp = icaltimezone_get_component (zone);
+
+	if (!(dl_comp = icalcomponent_get_first_component (icalcomp, ICAL_XDAYLIGHT_COMPONENT))) 
+		gtk_widget_set_sensitive ((GtkWidget *) prefs->daylight_saving, FALSE);
+	else 
+		gtk_widget_set_sensitive ((GtkWidget *) prefs->daylight_saving, TRUE);
+	 	
 	calendar_config_set_timezone (icaltimezone_get_location (zone));
 }
 
+static void
+daylight_saving_changed (GtkWidget *widget, CalendarPrefsDialog *prefs)
+{
+	gboolean set = gtk_toggle_button_get_active ((GtkToggleButton *) prefs->daylight_saving);
+	calendar_config_set_daylight_saving (set);
+	timezone_changed (widget, prefs);
+}
+
 static void
 start_of_day_changed (GtkWidget *widget, CalendarPrefsDialog *prefs)
 {
@@ -309,6 +325,8 @@ alarms_selection_changed (ESourceSelector *selector, CalendarPrefsDialog *prefs)
 	GSList *selection;
 	GSList *l;
 	GSList *groups;
+	ESource *source;
+	gchar *alarm;
 
 	/* first we clear all the alarm flags from all sources */
 	g_message ("Clearing selection");
@@ -316,8 +334,12 @@ alarms_selection_changed (ESourceSelector *selector, CalendarPrefsDialog *prefs)
 		ESourceGroup *group = E_SOURCE_GROUP (groups->data);
 		GSList *sources;
 		for (sources = e_source_group_peek_sources (group); sources; sources = sources->next) {
-			ESource *source = E_SOURCE (sources->data);
+			source = E_SOURCE (sources->data);
 
+			alarm = e_source_get_property (source, "alarm");
+			if (alarm && !g_ascii_strcasecmp (alarm, "never"))
+				continue;
+				
 			g_message ("Unsetting for %s", e_source_peek_name (source));
 			e_source_set_property (source, "alarm", "false");
 		}
@@ -327,6 +349,12 @@ alarms_selection_changed (ESourceSelector *selector, CalendarPrefsDialog *prefs)
 	   property on those sources */
 	selection = e_source_selector_get_selection (selector);
 	for (l = selection; l; l = l->next) {
+		source = E_SOURCE (l->data);
+
+		alarm = e_source_get_property (source, "alarm");
+		if (alarm && !g_ascii_strcasecmp (alarm, "never"))
+			continue;
+
 		g_message ("Setting for %s", e_source_peek_name (E_SOURCE (l->data)));
 		e_source_set_property (E_SOURCE (l->data), "alarm", "true");
 	}
@@ -351,6 +379,7 @@ setup_changes (CalendarPrefsDialog *prefs)
 		g_signal_connect (G_OBJECT (prefs->working_days[i]), "toggled", G_CALLBACK (working_days_changed), prefs);
 
 	g_signal_connect (G_OBJECT (prefs->timezone), "changed", G_CALLBACK (timezone_changed), prefs);
+	g_signal_connect (G_OBJECT (prefs->daylight_saving), "toggled", G_CALLBACK (daylight_saving_changed), prefs);
 
 	g_signal_connect (G_OBJECT (prefs->start_of_day), "changed", G_CALLBACK (start_of_day_changed), prefs);
 	g_signal_connect (G_OBJECT (prefs->end_of_day), "changed", G_CALLBACK (end_of_day_changed), prefs);
@@ -420,7 +449,7 @@ static void
 show_task_list_config (CalendarPrefsDialog *prefs)
 {
 	CalUnits units;
-	gboolean hide_completed_tasks;
+	gboolean hide_completed_tasks = FALSE;
 
 	set_color_picker (prefs->tasks_due_today_color, calendar_config_get_tasks_due_today_color ());
 	set_color_picker (prefs->tasks_overdue_color, calendar_config_get_tasks_overdue_color ());
@@ -468,7 +497,8 @@ show_alarms_config (CalendarPrefsDialog *prefs)
 	prefs->alarm_list_widget = e_source_selector_new (prefs->alarms_list);
 	atk_object_set_name (gtk_widget_get_accessible (prefs->alarm_list_widget), _("Selected Calendars for Alarms"));
 	gtk_container_add (GTK_CONTAINER (prefs->scrolled_window), prefs->alarm_list_widget);
-	initialize_selection (prefs->alarm_list_widget, prefs->alarms_list);
+	gtk_widget_show (prefs->alarm_list_widget);
+	initialize_selection (E_SOURCE_SELECTOR (prefs->alarm_list_widget), prefs->alarms_list);
 }
 
 /* Shows the current config settings in the dialog. */
@@ -478,12 +508,25 @@ show_config (CalendarPrefsDialog *prefs)
 	CalWeekdays working_days;
 	gint mask, day, week_start_day, time_divisions;
 	icaltimezone *zone;
-	gboolean sensitive;
+	gboolean sensitive, set = FALSE;
+	icalcomponent *icalcomp, *dl_comp;
+	char *location;
 
 	/* Timezone. */
-	zone = calendar_config_get_icaltimezone ();
+	location = calendar_config_get_timezone ();
+	zone = icaltimezone_get_builtin_timezone (location);
 	e_timezone_entry_set_timezone (E_TIMEZONE_ENTRY (prefs->timezone), zone);
+	g_free (location);
 
+	icalcomp = icaltimezone_get_component (zone);
+	if (!(dl_comp = icalcomponent_get_first_component (icalcomp, ICAL_XDAYLIGHT_COMPONENT))) 
+		gtk_widget_set_sensitive ((GtkWidget *) prefs->daylight_saving, FALSE);
+	else 
+		gtk_widget_set_sensitive ((GtkWidget *) prefs->daylight_saving, TRUE);
+	
+	set = calendar_config_get_daylight_saving ();
+	gtk_toggle_button_set_active ((GtkToggleButton *) prefs->daylight_saving, set);
+		
 	/* Working Days. */
 	working_days = calendar_config_get_working_days ();
 	mask = 1 << 0;
@@ -608,6 +651,7 @@ calendar_prefs_dialog_construct (CalendarPrefsDialog *prefs)
 
 	/* General tab */
 	prefs->timezone = glade_xml_get_widget (gui, "timezone");
+	prefs->daylight_saving = glade_xml_get_widget (gui, "daylight_cb");
 	for (i = 0; i < 7; i++)
 		prefs->working_days[i] = glade_xml_get_widget (gui, working_day_names[i]);
 	prefs->week_start_day = glade_xml_get_widget (gui, "week_start_day");
