@@ -385,7 +385,7 @@ e_calendar_view_add_event (ECalendarView *cal_view, ECal *client, time_t dtstart
 		    send_component_dialog ((GtkWindow *) gtk_widget_get_toplevel (GTK_WIDGET (cal_view)),
 					   client, comp, TRUE)) {
 			itip_send_comp (E_CAL_COMPONENT_METHOD_REQUEST, comp,
-				client, NULL, NULL);
+				client, NULL, NULL, NULL);
 		}
 	} else {
 		g_message (G_STRLOC ": Could not create the object!");
@@ -690,7 +690,7 @@ e_calendar_view_cut_clipboard (ECalendarView *cal_view)
 		    && cancel_component_dialog ((GtkWindow *) gtk_widget_get_toplevel (GTK_WIDGET (cal_view)),
 						event->comp_data->client, comp, TRUE))
 			itip_send_comp (E_CAL_COMPONENT_METHOD_CANCEL, comp,
-					event->comp_data->client, NULL, NULL);
+					event->comp_data->client, NULL, NULL, NULL);
 
 		e_cal_component_get_uid (comp, &uid);
 		if (e_cal_component_is_instance (comp)) {
@@ -765,7 +765,7 @@ e_calendar_view_copy_clipboard (ECalendarView *cal_view)
 	comp_str = icalcomponent_as_ical_string (vcal_comp);
 	gtk_clipboard_set_text (gtk_widget_get_clipboard (GTK_WIDGET (cal_view), clipboard_atom),
 				(const gchar *) comp_str,
-				g_utf8_strlen (comp_str, -1));
+				strlen (comp_str));
 
 	/* free memory */
 	icalcomponent_free (vcal_comp);
@@ -961,7 +961,7 @@ delete_event (ECalendarView *cal_view, ECalendarViewEvent *event)
 						event->comp_data->client,
 						comp, TRUE))
 			itip_send_comp (E_CAL_COMPONENT_METHOD_CANCEL, comp,
-					event->comp_data->client, NULL, NULL);
+					event->comp_data->client, NULL, NULL, NULL);
 
 		e_cal_component_get_uid (comp, &uid);
 		if (!uid || !*uid) {
@@ -1108,7 +1108,7 @@ e_calendar_view_delete_selected_occurrence (ECalendarView *cal_view)
 
 				e_cal_component_free_datetime (&range.datetime);
 			}
-			itip_send_comp (E_CAL_COMPONENT_METHOD_CANCEL, comp, event->comp_data->client, NULL, NULL);
+			itip_send_comp (E_CAL_COMPONENT_METHOD_CANCEL, comp, event->comp_data->client, NULL, NULL, NULL);
 		}
 
 		if (is_instance)
@@ -1239,9 +1239,8 @@ on_save_as (EPopup *ep, EPopupItem *pitem, void *data)
 	GList *selected;
 	char *filename;
 	char *ical_string;
-	FILE *file;
 	ECalendarViewEvent *event;
-
+	
 	selected = e_calendar_view_get_selected_events (cal_view);
 	if (!selected)
 		return;
@@ -1256,16 +1255,9 @@ on_save_as (EPopup *ep, EPopupItem *pitem, void *data)
 		g_warning ("Couldn't convert item to a string");
 		return;
 	}
-	
-	file = g_fopen (filename, "w");
-	if (file == NULL) {
-		g_warning ("Couldn't save item");
-		return;
-	}
-	
-	fprintf (file, "%s", ical_string);
+
+	e_write_file_uri (filename, ical_string);
 	g_free (ical_string);
-	fclose (file);
 
 	g_list_free (selected);
 }
@@ -1515,7 +1507,7 @@ on_forward (EPopup *ep, EPopupItem *pitem, void *data)
 
 		comp = e_cal_component_new ();
 		e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (event->comp_data->icalcomp));
-		itip_send_comp (E_CAL_COMPONENT_METHOD_PUBLISH, comp, event->comp_data->client, NULL, NULL);
+		itip_send_comp (E_CAL_COMPONENT_METHOD_PUBLISH, comp, event->comp_data->client, NULL, NULL, NULL);
 
 		g_list_free (selected);
 		g_object_unref (comp);
@@ -1918,7 +1910,8 @@ e_calendar_view_new_appointment_for (ECalendarView *cal_view,
  *
  * Opens an event editor dialog for a new appointment. The appointment's
  * start and end times are set to the currently selected time range in
- * the calendar view.
+ * the calendar view, with exception when this time is in past, then
+ * current date is used too.
  */
 void
 e_calendar_view_new_appointment_full (ECalendarView *cal_view, gboolean all_day, gboolean meeting)
@@ -1927,7 +1920,8 @@ e_calendar_view_new_appointment_full (ECalendarView *cal_view, gboolean all_day,
 
 	g_return_if_fail (E_IS_CALENDAR_VIEW (cal_view));
 
-	if (!e_calendar_view_get_selected_time_range (cal_view, &dtstart, &dtend)) {
+	if (!e_calendar_view_get_selected_time_range (cal_view, &dtstart, &dtend) ||
+	    dtstart / (60 * 60 * 24) < time (NULL) / (60 * 60 * 24)) {
 		dtstart = time (NULL);
 		dtend = dtstart + 3600;
 	}
@@ -2032,7 +2026,7 @@ e_calendar_view_modify_and_send (ECalComponent *comp,
 	if (e_cal_modify_object (client, e_cal_component_get_icalcomponent (comp), mod, NULL)) {
 		if (itip_organizer_is_user (comp, client) &&
 		    send_component_dialog (toplevel, client, comp, new))
-			itip_send_comp (E_CAL_COMPONENT_METHOD_REQUEST, comp, client, NULL, NULL);
+			itip_send_comp (E_CAL_COMPONENT_METHOD_REQUEST, comp, client, NULL, NULL, NULL);
 	} else {
 		g_message (G_STRLOC ": Could not update the object!");
 	}
@@ -2138,6 +2132,7 @@ e_calendar_view_get_tooltips (ECalendarViewEventData *data)
 
 	default_zone = e_calendar_view_get_timezone  (data->cal_view);
 	pevent = data->get_view_event (data->cal_view, data->day, data->event_num);
+
 	client = pevent->comp_data->client;
 
 	clone_comp = icalcomponent_new_clone (pevent->comp_data->icalcomp);
